@@ -1,7 +1,16 @@
+import pathlib
+
+repo_root = pathlib.Path(".")
+
+BASE_URL = "https://research.zozo.com/data_release/shift15m"
+OUTFIT_JSON_URL = (
+    "https://research.zozo.com/data_release/shift15m/label/iqon_outfits.json"
+)
 JSONL = "jsonl"
 PICKLE = "pickle"
-ROOT = "data"
-FEATURE_ROOT = "data/features"
+ROOT = str(repo_root / "data")
+DOWNLOAD = "download"
+FEATURE_ROOT = str(repo_root / "data/features")
 RECORDS = "records"
 CATEGORY_ID_MAX = 20
 YEAES = list(map(str, range(2010, 2021)))
@@ -18,6 +27,23 @@ SUB_CATEGORIES = [
 ]
 # fmt: on
 
+FILES_NUM_LIKES_REGRESSION = [
+    "xy_00.pickle",
+    "xy_01.pickle",
+    "xy_02.pickle",
+    "xy_03.pickle",
+    "xy_04.pickle",
+    "xy_05.pickle",
+    "xy_06.pickle",
+    "xy_07.pickle",
+    "xy_08.pickle",
+    "xy_09.pickle",
+]
+
+FILES_SUM_PRICES_REGRESSION = [
+    "sumprices.pickle",
+]
+
 
 class Keys:
     USER = "user"
@@ -30,6 +56,11 @@ class Keys:
     SUBCATEGORY_ID = "category_id2"
 
 
+class ItemCatalog:
+    DEFAULT_FILE = "item_catalog.txt"
+    YEAR = "year"
+
+
 class Tasks:
     NUM_LIKES_REGRESSION = "num_likes_regression"
     SUM_PRICES_REGRESSION = "sum_prices_regression"
